(* ©Harald E Brandt. You may use any of this code for any purpose you like.
It is meant to change old Mori internal links so that they point to the corresponding file in DEVONthink Pro instead. It will only treat links to files that belong to the same group (reside in the same folder) as the file that contains the link. Before this script is run, it is necessary to run the script "strip rtfd in names of Notebase" that changes all names of rtfd files imported from Mori so that the name of the item in DEVONthink no longer includes the file extension "rtfd". After this script is run, run the semi-automatic script "Mori other-group links in Notebase" to modify the links that point to files in some other group, or links that the other script couldn't fix automatically.
It basically works as follows:
It iterates through all rtf and rtfd files in a database named "Notebase" and searches for all link URLs that start with "mori://", then it searches the same group (folder) for a file that has the same name as the text of the link minus any leading or trailing white space or linefeeds, then it sets the link URL to that file (i.e the new link URL will be something like: "x-devonthink-item://162E0728-9051-4EBC-8C85-35D809D3A665")
It will also remove some bogus links in linefeeds that seem to be some old leftovers from Mori; those links are inaccessible anyway since the "text" of them is simply a linefeed. Those bogus links seem to occur sometimes right after textual links. This script will remove those links (but keeping the linefeed of course).
In all of the changes described above, it will first save the file and then set the modification date to what it was before the change, i.e all modification dates are preserved.
In the end, it will report the result of the number of files changed, the number of changed links, and the number of fixed bogus links. In my case, the following was the result of running it in AppleScriptObjC Exlorer:
000,0000 -- Start --
043,6882 Result
--> Number of changes:
Number of changed files: 103
Number of changed links: 158
Number of bogus links (orphan linefeeds with an invisible link that we removed): 39
000,0017 -- End -- (~47,968s)

As you can see, it took 48 seconds (on a MacBook Pro Retina). I am sure the script can be optimized, but it is not worth the effort. If you want to run this in AppleScript Editor instead, you will have to replace the Objective-C call to NSString with your own method for stripping white space.
*)
set nrOfChangedFiles to 0
set nrOfChangedLinks to 0
set nrOfBogusLinks to 0
tell application "DEVONthink Pro"
	repeat with aGroup in parents of database "Notebase"
		if kind of aGroup is "Group" and name of aGroup is not in {"Trash", "Inbox", "Tags", "Mobile Sync"} then
			repeat with anRTF in (children of aGroup whose kind is "RTFD" or kind is "RTF")
				set anRTFisChanged to false --a flag so we can count the number of files we changed
				set allURLs to URL of attribute runs of rich text of anRTF --list of URLs, possibly with missing value
				set allRuns to attribute runs of rich text of anRTF --we need to pick them here rather than inside the next loop because we may later remove bogus links at linefeeds which will lower the number of attribute runs, so both allURLs and allRuns must stay in synch regarding the index into the attribute run.
				-- For picking the URL, it would seem natural to pick that in the loop by taking the URL of an item of allRuns, but it does not seem to work for some inexplicable reason!
				repeat with i from 1 to count allURLs --note that I can't use 'contents of ...' because conflict of terms!!
					set anURL to item i of allURLs
					if anURL is not missing value and texts 1 thru 7 of anURL is "mori://" then
						set theText to text of item i of allRuns
						-- For some inexplicable weird reason, "item i of attribute runs of …" is NOT always the same item as "attribute run i of …"!!? It should be, but for some longer texts in some files, the same item can have different "i" indexes! (By 1 or perhaps 2 units.) Weird bug, so we have to be very consistent only doing "item i of ..."
						-- To set the URL to a new value, we can't do that on theText, and not even on the attribute run of anRTF, since that is data rather than pointers into the actual document. Instead we have to target the attribute run of the text of a viewer window. However, the next weird bug is that "item i of attribute runs of text of viewer window 1" is NOT always the same item as "item i of attribute runs of rich text of anRTF"!!? Again, the same item can have different "i" indexes! It appears that the ONLY way to get the right item is to do a search for that item! Scary, but if we search for both its text and URL I hope we are safe... The text can actually be a simple linefeed so we should have the URL match before the text match to gains some speed.
						set selection of viewer window 1 to {anRTF}
						set allViewURLs to URL of attribute runs of text of viewer window 1 --list of URLs or 'missing value'
						set allViewTexts to text of attribute runs of text of viewer window 1
						set theViewRun to missing value --just in case something is wrong, we will check if it remains missing value (should never happen)
						repeat with j from 1 to count allViewURLs
							-- It does NOT work with "URL of item j of attribute runs of text of viewer window 1 is …" if it is missing value, but it DOES work with "item j of URL of attribute runs of text of viewer window 1 is …"! Weird!! That's why this repeat loop has to use explicit indexing rather than "fast iteration" using "repeat with aViewRun in …"
							if item j of allViewURLs is anURL and item j of allViewTexts is theText then
								set theViewRun to (a reference to item j of attribute runs of text of viewer window 1) --this is a reference to the attribute run in the window.
								exit repeat
							end if
						end repeat
						if theViewRun is missing value then
							tell me to display dialog "Oh Shit! There is no view run that matches the URL!" buttons {"Sigh!"} default button 1
							return
						end if
						-- Now, theText can either be a real text string, possibly with trailing white space and/or linefeed, or it can be a single linefeed with a bogus link. In the latter case, it is just som leftover of a useless inaccessible link that we should simply remove, so we set the URL of that linefeed to missing value. In the former case, however, we will first strip trailing (or leading) white space and then search for a file in the same folder that has the same name as the linked text.
						if theText is linefeed then
							set modDate to modification date of anRTF
							set URL of theViewRun to missing value
							save viewer window 1
							set modification date of anRTF to modDate
							set nrOfBogusLinks to nrOfBogusLinks + 1
							set anRTFisChanged to true
						else
							-- Strip white space from theText since we will search for a file name that matches it, and we don't want any trailing spaces or LF:
							set theText to current application's NSString's stringWithString_(theText)'s stringByTrimmingCharactersInSet_(current application's NSCharacterSet's whitespaceAndNewlineCharacterSet) as text
							repeat with aChild in children of aGroup
								if name of aChild is theText and kind of aChild is in {"RTFD", "RTF"} then
									set modDate to modification date of anRTF
									set URL of theViewRun to reference URL of aChild
									save viewer window 1
									set modification date of anRTF to modDate
									set nrOfChangedLinks to nrOfChangedLinks + 1
									set anRTFisChanged to true
									exit repeat
								end if
							end repeat
						end if
					end if
				end repeat
				if anRTFisChanged then set nrOfChangedFiles to nrOfChangedFiles + 1
			end repeat
		end if
	end repeat
end tell
return "Number of changes:" & return & ¬
	"Number of changed files: " & nrOfChangedFiles & return & ¬
	"Number of changed links: " & nrOfChangedLinks & return & ¬
	"Number of bogus links (orphan linefeeds with an invisible link that we removed): " & nrOfBogusLinks